@@ -9,7 +9,7 @@
 #'
 #' @family class metrics
 #' @family relevance metrics
-#' @templateVar metric_fn f_meas
+#' @templateVar fn f_meas
 #' @template event_first
 #' @template multiclass
 #' @template return
@@ -57,9 +57,9 @@ f_meas.data.frame <- function(data,
                               case_weights = NULL,
                               event_level = yardstick_event_level(),
                               ...) {
-  metric_summarizer(
-    metric_nm = "f_meas",
-    metric_fn = f_meas_vec,
+  class_metric_summarizer(
+    name = "f_meas",
+    fn = f_meas_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
@@ -67,16 +67,16 @@ f_meas.data.frame <- function(data,
     na_rm = na_rm,
     case_weights = !!enquo(case_weights),
     event_level = event_level,
-    metric_fn_options = list(beta = beta)
+    fn_options = list(beta = beta)
   )
 }
 
 #' @export
-f_meas.table <- function (data,
-                          beta = 1,
-                          estimator = NULL,
-                          event_level = yardstick_event_level(),
-                          ...) {
+f_meas.table <- function(data,
+                         beta = 1,
+                         estimator = NULL,
+                         event_level = yardstick_event_level(),
+                         ...) {
   check_table(data)
   estimator <- finalize_estimator(data, estimator)
 
@@ -107,28 +107,29 @@ f_meas_vec <- function(truth,
                        case_weights = NULL,
                        event_level = yardstick_event_level(),
                        ...) {
+  abort_if_class_pred(truth)
+  estimate <- as_factor_from_class_pred(estimate)
+
   estimator <- finalize_estimator(truth, estimator)
 
-  f_meas_impl <- function(truth, estimate, ..., beta = 1, case_weights = NULL) {
-    check_dots_empty()
-    data <- yardstick_table(truth, estimate, case_weights = case_weights)
-    f_meas_table_impl(data, estimator, event_level, beta = beta)
+  check_class_metric(truth, estimate, case_weights, estimator)
+
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
   }
 
-  metric_vec_template(
-    metric_impl = f_meas_impl,
-    truth = truth,
-    estimate = estimate,
-    na_rm = na_rm,
-    estimator = estimator,
-    case_weights = case_weights,
-    cls = "factor",
-    beta = beta
-  )
+  data <- yardstick_table(truth, estimate, case_weights = case_weights)
+  f_meas_table_impl(data, estimator, event_level, beta)
 }
 
-f_meas_table_impl <- function(data, estimator, event_level, beta = 1) {
-  if(is_binary(estimator)) {
+f_meas_table_impl <- function(data, estimator, event_level, beta) {
+  if (is_binary(estimator)) {
     f_meas_binary(data, event_level, beta)
   } else {
     w <- get_weights(data, estimator)
@@ -142,18 +143,18 @@ f_meas_binary <- function(data, event_level, beta = 1) {
   rec <- recall_binary(data, event_level)
 
   # if precision and recall are both 0, return 0 not NA
-  if(isTRUE(precision == 0 & rec == 0)) {
+  if (isTRUE(precision == 0 & rec == 0)) {
     return(0)
   }
 
-  (1 + beta ^ 2) * precision * rec / ((beta ^ 2 * precision) + rec)
+  (1 + beta^2) * precision * rec / ((beta^2 * precision) + rec)
 }
 
 f_meas_multiclass <- function(data, estimator, beta = 1) {
   precision <- precision_multiclass(data, estimator)
   rec <- recall_multiclass(data, estimator)
 
-  res <- (1 + beta ^ 2) * precision * rec / ((beta ^ 2 * precision) + rec)
+  res <- (1 + beta^2) * precision * rec / ((beta^2 * precision) + rec)
 
   # if precision and recall are both 0, define this as 0 not NA
   # this is the case when tp == 0 and is well defined
