@@ -17,7 +17,7 @@
 #' as defined in Powers, David M W (2011), equation (42).
 #'
 #' @family class metrics
-#' @templateVar metric_fn j_index
+#' @templateVar fn j_index
 #' @template event_first
 #' @template multiclass
 #' @template return
@@ -55,9 +55,9 @@ j_index.data.frame <- function(data,
                                case_weights = NULL,
                                event_level = yardstick_event_level(),
                                ...) {
-  metric_summarizer(
-    metric_nm = "j_index",
-    metric_fn = j_index_vec,
+  class_metric_summarizer(
+    name = "j_index",
+    fn = j_index_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
@@ -101,27 +101,29 @@ j_index_vec <- function(truth,
                         case_weights = NULL,
                         event_level = yardstick_event_level(),
                         ...) {
+  abort_if_class_pred(truth)
+  estimate <- as_factor_from_class_pred(estimate)
+
   estimator <- finalize_estimator(truth, estimator)
 
-  j_index_impl <- function(truth, estimate, ..., case_weights = NULL) {
-    check_dots_empty()
-    data <- yardstick_table(truth, estimate, case_weights = case_weights)
-    j_index_table_impl(data, estimator, event_level)
+  check_class_metric(truth, estimate, case_weights, estimator)
+
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
   }
 
-  metric_vec_template(
-    metric_impl = j_index_impl,
-    truth = truth,
-    estimate = estimate,
-    na_rm = na_rm,
-    cls = "factor",
-    estimator = estimator,
-    case_weights = case_weights
-  )
+  data <- yardstick_table(truth, estimate, case_weights = case_weights)
+  j_index_table_impl(data, estimator, event_level)
 }
 
 j_index_table_impl <- function(data, estimator, event_level) {
-  if(is_binary(estimator)) {
+  if (is_binary(estimator)) {
     j_index_binary(data, event_level)
   } else {
     w <- get_weights(data, estimator)
