@@ -11,7 +11,7 @@
 #'
 #' @family class metrics
 #' @family sensitivity metrics
-#' @templateVar metric_fn npv
+#' @templateVar fn npv
 #' @template event_first
 #' @template multiclass
 #' @template return
@@ -46,18 +46,20 @@ npv.data.frame <- function(data,
                            prevalence = NULL,
                            estimator = NULL,
                            na_rm = TRUE,
+                           case_weights = NULL,
                            event_level = yardstick_event_level(),
                            ...) {
-  metric_summarizer(
-    metric_nm = "npv",
-    metric_fn = npv_vec,
+  class_metric_summarizer(
+    name = "npv",
+    fn = npv_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
     estimator = estimator,
     na_rm = na_rm,
+    case_weights = !!enquo(case_weights),
     event_level = event_level,
-    metric_fn_options = list(prevalence = prevalence)
+    fn_options = list(prevalence = prevalence)
   )
 }
 
@@ -94,41 +96,40 @@ npv_vec <- function(truth,
                     prevalence = NULL,
                     estimator = NULL,
                     na_rm = TRUE,
+                    case_weights = NULL,
                     event_level = yardstick_event_level(),
                     ...) {
+  abort_if_class_pred(truth)
+  estimate <- as_factor_from_class_pred(estimate)
+
   estimator <- finalize_estimator(truth, estimator)
 
-  npv_impl <- function(truth, estimate, prevalence) {
-    xtab <- vec2table(
-      truth = truth,
-      estimate = estimate
-    )
+  check_class_metric(truth, estimate, case_weights, estimator)
 
-    npv_table_impl(xtab, estimator, event_level, prevalence = prevalence)
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
   }
 
-  metric_vec_template(
-    metric_impl = npv_impl,
-    truth = truth,
-    estimate = estimate,
-    na_rm = na_rm,
-    estimator = estimator,
-    cls = "factor",
-    prevalence = prevalence
-  )
+  data <- yardstick_table(truth, estimate, case_weights = case_weights)
+  npv_table_impl(data, estimator, event_level, prevalence = prevalence)
 }
 
 npv_table_impl <- function(data,
                            estimator,
                            event_level,
                            prevalence = NULL) {
-
-  if(is_binary(estimator)) {
+  if (is_binary(estimator)) {
     npv_binary(data, event_level, prevalence)
   } else {
     w <- get_weights(data, estimator)
     out_vec <- npv_multiclass(data, estimator, prevalence)
-    weighted.mean(out_vec, w)
+    stats::weighted.mean(out_vec, w)
   }
 }
 
@@ -136,8 +137,9 @@ npv_binary <- function(data, event_level, prevalence = NULL) {
   positive <- pos_val(data, event_level)
   negative <- neg_val(data, event_level)
 
-  if (is.null(prevalence))
+  if (is.null(prevalence)) {
     prevalence <- sum(data[, positive]) / sum(data)
+  }
 
   sens <- sens_binary(data, event_level)
   spec <- spec_binary(data, event_level)
@@ -146,12 +148,12 @@ npv_binary <- function(data, event_level, prevalence = NULL) {
 
 npv_multiclass <- function(data, estimator, prevalence = NULL) {
   if (is.null(prevalence)) {
-    tpfn     <- colSums(data)
+    tpfn <- colSums(data)
     tptnfpfn <- rep(sum(data), times = nrow(data))
 
     if (is_micro(estimator)) {
-      tpfn       <- sum(tpfn)
-      tptnfpfn   <- sum(tptnfpfn)
+      tpfn <- sum(tpfn)
+      tptnfpfn <- sum(tptnfpfn)
     }
 
     prevalence <- tpfn / tptnfpfn
