@@ -11,7 +11,7 @@
 #'
 #' @family class metrics
 #' @family sensitivity metrics
-#' @templateVar metric_fn ppv
+#' @templateVar fn ppv
 #' @template event_first
 #' @template multiclass
 #' @template return
@@ -55,9 +55,9 @@ ppv.data.frame <- function(data,
                            case_weights = NULL,
                            event_level = yardstick_event_level(),
                            ...) {
-  metric_summarizer(
-    metric_nm = "ppv",
-    metric_fn = ppv_vec,
+  class_metric_summarizer(
+    name = "ppv",
+    fn = ppv_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
@@ -65,7 +65,7 @@ ppv.data.frame <- function(data,
     na_rm = na_rm,
     case_weights = !!enquo(case_weights),
     event_level = event_level,
-    metric_fn_options = list(prevalence = prevalence)
+    fn_options = list(prevalence = prevalence)
   )
 }
 
@@ -116,35 +116,42 @@ ppv_vec <- function(truth,
                     case_weights = NULL,
                     event_level = yardstick_event_level(),
                     ...) {
+  abort_if_class_pred(truth)
+  estimate <- as_factor_from_class_pred(estimate)
+
   estimator <- finalize_estimator(truth, estimator)
 
-  ppv_impl <- function(truth,
-                       estimate,
-                       ...,
-                       prevalence = NULL,
-                       case_weights = NULL) {
-    check_dots_empty()
-    data <- yardstick_table(truth, estimate, case_weights = case_weights)
-    ppv_table_impl(data, estimator, event_level, prevalence = prevalence)
+  check_class_metric(truth, estimate, case_weights, estimator)
+
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
   }
 
-  metric_vec_template(
-    metric_impl = ppv_impl,
-    truth = truth,
-    estimate = estimate,
-    na_rm = na_rm,
-    estimator = estimator,
-    case_weights = case_weights,
-    cls = "factor",
-    prevalence = prevalence
-  )
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
+  }
+
+  data <- yardstick_table(truth, estimate, case_weights = case_weights)
+  ppv_table_impl(data, estimator, event_level, prevalence = prevalence)
 }
 
 ppv_table_impl <- function(data,
                            estimator,
                            event_level,
                            prevalence = NULL) {
-  if(is_binary(estimator)) {
+  if (is_binary(estimator)) {
     ppv_binary(data, event_level, prevalence)
   } else {
     w <- get_weights(data, estimator)
@@ -170,12 +177,12 @@ ppv_multiclass <- function(data, estimator, prevalence = NULL) {
   # prevalence is explicitely set. In that case, that value
   # is used which alters the result
   if (is.null(prevalence)) {
-    tpfn     <- colSums(data)
+    tpfn <- colSums(data)
     tptnfpfn <- rep(sum(data), times = nrow(data))
 
     if (is_micro(estimator)) {
-      tpfn       <- sum(tpfn)
-      tptnfpfn   <- sum(tptnfpfn)
+      tpfn <- sum(tpfn)
+      tptnfpfn <- sum(tptnfpfn)
     }
 
     prevalence <- tpfn / tptnfpfn
