@@ -16,7 +16,7 @@
 #'
 #' @family class metrics
 #' @family sensitivity metrics
-#' @templateVar metric_fn spec
+#' @templateVar fn spec
 #' @template event_first
 #' @template multiclass
 #' @template return
@@ -36,7 +36,7 @@
 #' @template examples-class
 #'
 #' @export
-spec <-  function(data, ...) {
+spec <- function(data, ...) {
   UseMethod("spec")
 }
 spec <- new_class_metric(
@@ -54,9 +54,9 @@ spec.data.frame <- function(data,
                             case_weights = NULL,
                             event_level = yardstick_event_level(),
                             ...) {
-  metric_summarizer(
-    metric_nm = "spec",
-    metric_fn = spec_vec,
+  class_metric_summarizer(
+    name = "spec",
+    fn = spec_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
@@ -72,7 +72,6 @@ spec.table <- function(data,
                        estimator = NULL,
                        event_level = yardstick_event_level(),
                        ...) {
-
   check_table(data)
   estimator <- finalize_estimator(data, estimator)
 
@@ -81,7 +80,6 @@ spec.table <- function(data,
     .estimator = estimator,
     .estimate = spec_table_impl(data, estimator, event_level)
   )
-
 }
 
 #' @export
@@ -102,30 +100,32 @@ spec_vec <- function(truth,
                      case_weights = NULL,
                      event_level = yardstick_event_level(),
                      ...) {
+  abort_if_class_pred(truth)
+  estimate <- as_factor_from_class_pred(estimate)
+
   estimator <- finalize_estimator(truth, estimator)
 
-  spec_impl <- function(truth, estimate, ..., case_weights = NULL) {
-    check_dots_empty()
-    data <- yardstick_table(truth, estimate, case_weights = case_weights)
-    spec_table_impl(data, estimator, event_level)
+  check_class_metric(truth, estimate, case_weights, estimator)
+
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
   }
 
-  metric_vec_template(
-    metric_impl = spec_impl,
-    truth = truth,
-    estimate = estimate,
-    na_rm = na_rm,
-    estimator = estimator,
-    case_weights = case_weights,
-    cls = "factor"
-  )
+  data <- yardstick_table(truth, estimate, case_weights = case_weights)
+  spec_table_impl(data, estimator, event_level)
 }
 
 # ------------------------------------------------------------------------------
 
 #' @rdname spec
 #' @export
-specificity <-  function(data, ...) {
+specificity <- function(data, ...) {
   UseMethod("specificity")
 }
 specificity <- new_class_metric(
@@ -143,9 +143,9 @@ specificity.data.frame <- function(data,
                                    case_weights = NULL,
                                    event_level = yardstick_event_level(),
                                    ...) {
-  metric_summarizer(
-    metric_nm = "specificity",
-    metric_fn = spec_vec,
+  class_metric_summarizer(
+    name = "specificity",
+    fn = spec_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
@@ -161,7 +161,6 @@ specificity.table <- function(data,
                               estimator = NULL,
                               event_level = yardstick_event_level(),
                               ...) {
-
   check_table(data)
   estimator <- finalize_estimator(data, estimator)
 
@@ -170,7 +169,6 @@ specificity.table <- function(data,
     .estimator = estimator,
     .estimate = spec_table_impl(data, estimator, event_level)
   )
-
 }
 
 #' @export
@@ -189,7 +187,7 @@ specificity_vec <- spec_vec
 # ------------------------------------------------------------------------------
 
 spec_table_impl <- function(data, estimator, event_level) {
-  if(is_binary(estimator)) {
+  if (is_binary(estimator)) {
     spec_binary(data, event_level)
   } else {
     w <- get_weights(data, estimator)
@@ -219,11 +217,11 @@ spec_binary <- function(data, event_level) {
 spec_multiclass <- function(data, estimator) {
   n <- sum(data)
 
-  tp   <- diag(data)
+  tp <- diag(data)
   tpfp <- rowSums(data)
   tpfn <- colSums(data)
-  tn   <- n - (tpfp + tpfn - tp)
-  fp   <- tpfp - tp
+  tn <- n - (tpfp + tpfn - tp)
+  fp <- tpfp - tp
 
   numer <- tn
   denom <- tn + fp
@@ -239,7 +237,7 @@ spec_multiclass <- function(data, estimator) {
   }
 
   # set `na.rm = TRUE` to remove undefined values from weighted computation (#98)
-  if(is_micro(estimator)) {
+  if (is_micro(estimator)) {
     numer <- sum(numer, na.rm = TRUE)
     denom <- sum(denom, na.rm = TRUE)
   }
@@ -288,7 +286,7 @@ warn_spec_undefined_multiclass <- function(events, counts) {
 }
 
 warn_spec_undefined <- function(message, events, counts, ..., class = character()) {
-  rlang::warn(
+  warn(
     message = message,
     class = c(class, "yardstick_warning_spec_undefined"),
     events = events,
