@@ -6,7 +6,7 @@
 #'
 #' @family numeric metrics
 #' @family accuracy metrics
-#' @templateVar metric_fn huber_loss
+#' @templateVar fn huber_loss
 #' @template return
 #'
 #' @inheritParams rmse
@@ -41,16 +41,16 @@ huber_loss.data.frame <- function(data,
                                   na_rm = TRUE,
                                   case_weights = NULL,
                                   ...) {
-  metric_summarizer(
-    metric_nm = "huber_loss",
-    metric_fn = huber_loss_vec,
+  numeric_metric_summarizer(
+    name = "huber_loss",
+    fn = huber_loss_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
     na_rm = na_rm,
     case_weights = !!enquo(case_weights),
     # Extra argument for huber_loss_impl()
-    metric_fn_options = list(delta = delta)
+    fn_options = list(delta = delta)
   )
 }
 
@@ -62,30 +62,34 @@ huber_loss_vec <- function(truth,
                            na_rm = TRUE,
                            case_weights = NULL,
                            ...) {
-  metric_vec_template(
-    metric_impl = huber_loss_impl,
-    truth = truth,
-    estimate = estimate,
-    na_rm = na_rm,
-    case_weights = case_weights,
-    cls = "numeric",
-    delta = delta
-  )
+  check_numeric_metric(truth, estimate, case_weights)
+
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
+  }
+
+  huber_loss_impl(truth, estimate, delta, case_weights)
 }
 
 huber_loss_impl <- function(truth,
                             estimate,
-                            ...,
-                            delta = 1,
-                            case_weights = NULL) {
+                            delta,
+                            case_weights,
+                            call = caller_env()) {
   # Weighted Huber Loss implementation confirmed against matlab:
   # https://www.mathworks.com/help/deeplearning/ref/dlarray.huber.html
 
-  if (!rlang::is_bare_numeric(delta, n = 1L)) {
-    abort("`delta` must be a single numeric value.")
+  if (!is_bare_numeric(delta, n = 1L)) {
+    abort("`delta` must be a single numeric value.", call = call)
   }
   if (!(delta >= 0)) {
-    abort("`delta` must be a positive value.")
+    abort("`delta` must be a positive value.", call = call)
   }
 
   a <- truth - estimate
