@@ -14,7 +14,7 @@
 #'  data (i.e. from resamples). See the examples.
 #'
 #' @family curve metrics
-#' @templateVar metric_fn roc_curve
+#' @templateVar fn roc_curve
 #' @template multiclass-curve
 #' @template event_first
 #'
@@ -78,14 +78,12 @@ roc_curve.data.frame <- function(data,
                                  options = list()) {
   check_roc_options_deprecated("roc_curve", options)
 
-  estimate <- dots_to_estimate(data, !!! enquos(...))
-
-  result <- metric_summarizer(
-    metric_nm = "roc_curve",
-    metric_fn = roc_curve_vec,
+  result <- curve_metric_summarizer(
+    name = "roc_curve",
+    fn = roc_curve_vec,
     data = data,
     truth = !!enquo(truth),
-    estimate = !!estimate,
+    ...,
     na_rm = na_rm,
     event_level = event_level,
     case_weights = !!enquo(case_weights)
@@ -100,32 +98,29 @@ roc_curve_vec <- function(truth,
                           event_level = yardstick_event_level(),
                           case_weights = NULL,
                           ...) {
+  abort_if_class_pred(truth)
+
   estimator <- finalize_estimator(truth, metric_class = "roc_curve")
 
-  # estimate here is a matrix of class prob columns
-  roc_curve_impl <- function(truth,
-                             estimate,
-                             ...,
-                             case_weights = NULL) {
-    check_dots_empty()
+  check_prob_metric(truth, estimate, case_weights, estimator)
 
-    roc_curve_estimator_impl(
-      truth = truth,
-      estimate = estimate,
-      estimator = estimator,
-      event_level = event_level,
-      case_weights = case_weights
-    )
+  if (na_rm) {
+    result <- yardstick_remove_missing(truth, estimate, case_weights)
+
+    truth <- result$truth
+    estimate <- result$estimate
+    case_weights <- result$case_weights
+  } else if (yardstick_any_missing(truth, estimate, case_weights)) {
+    return(NA_real_)
   }
 
-  metric_vec_template(
-    metric_impl = roc_curve_impl,
+  # estimate here is a matrix of class prob columns
+  roc_curve_estimator_impl(
     truth = truth,
     estimate = estimate,
-    na_rm = na_rm,
     estimator = estimator,
-    case_weights = case_weights,
-    cls = c("factor", "numeric")
+    event_level = event_level,
+    case_weights = case_weights
   )
 }
 
@@ -201,7 +196,7 @@ roc_curve_multiclass <- function(truth,
                                  estimate,
                                  case_weights) {
   one_vs_all_with_level(
-    metric_fn = roc_curve_binary,
+    fn = roc_curve_binary,
     truth = truth,
     estimate = estimate,
     case_weights = case_weights
@@ -214,20 +209,19 @@ check_roc_options_deprecated <- function(what, options) {
   }
 }
 warn_roc_options_deprecated <- function(what) {
-  message <- c(
-    sprintf("The `options` argument of `%s()` is deprecated as of yardstick 1.0.0.", what),
-    "This argument no longer has any effect, and is being ignored.",
-    "Use the pROC package directly if you need these features."
+  lifecycle::deprecate_warn(
+    when = "1.0.0",
+    what = I(sprintf("The `options` argument of `%s()`", what)),
+    details = paste(
+      "This argument no longer has any effect, and is being ignored.",
+      "Use the pROC package directly if you need these features."
+    )
   )
-  message <- paste0(message, collapse = "\n")
-
-  warn_deprecated(message)
 }
 
 
 # Dynamically exported
 autoplot.roc_df <- function(object, ...) {
-
   `%+%` <- ggplot2::`%+%`
 
   # Base chart
@@ -235,30 +229,25 @@ autoplot.roc_df <- function(object, ...) {
 
   # Add in group interactions if required
   if (inherits(object, "grouped_roc_df")) {
-
     grps <- dplyr::groups(object)
 
     grps_chr <- paste0(dplyr::group_vars(object), collapse = "_")
 
     interact_expr <- list(
-      color = rlang::expr(interaction(!!! grps, sep = "_"))
+      color = expr(interaction(!!!grps, sep = "_"))
     )
 
     roc_chart <- roc_chart %+%
       ggplot2::labs(color = grps_chr)
-
-  }
-  else {
-
+  } else {
     interact_expr <- list()
-
   }
 
   # splice in the group interactions, or do nothing
   aes_spliced <- ggplot2::aes(
     x = 1 - specificity,
     y = sensitivity,
-    !!! interact_expr
+    !!!interact_expr
   )
 
   # build the graph
