@@ -5,11 +5,9 @@
 #include <R_ext/Rdynload.h>
 
 extern SEXP yardstick_mcc_multiclass_impl(SEXP);
-extern SEXP yardstick_pr_curve_binary_impl(SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
   {"yardstick_mcc_multiclass_impl",    (DL_FUNC) &yardstick_mcc_multiclass_impl, 1},
-  {"yardstick_pr_curve_binary_impl",   (DL_FUNC) &yardstick_pr_curve_binary_impl, 3},
   {NULL, NULL, 0}
 };
 
