@@ -1,16 +1,16 @@
-test_that('npv', {
+test_that("npv", {
   lst <- data_altman()
   pathology <- lst$pathology
   path_tbl <- lst$path_tbl
 
   expect_equal(
     npv(pathology, truth = "pathology", estimate = "scan")[[".estimate"]],
-    2/3,
+    2 / 3,
     tolerance = .001
   )
   expect_equal(
     npv(path_tbl)[[".estimate"]],
-    2/3,
+    2 / 3,
     tolerance = .001
   )
   expect_equal(
@@ -41,7 +41,7 @@ test_that("`event_level = 'second'` works", {
 
 # ------------------------------------------------------------------------------
 
-test_that('Three class', {
+test_that("Three class", {
   multi_ex <- data_three_by_three()
   micro <- data_three_by_three_micro()
   micro$prev <- (micro$tp + micro$fn) / (micro$p + micro$n)
@@ -56,24 +56,54 @@ test_that('Three class', {
   )
   expect_equal(
     npv(multi_ex, estimator = "micro")[[".estimate"]],
-    with(micro,
-         (sum(tn) / sum(n) * sum((1 - prev))) /
-         ( (1 - sum(tp) / sum(p)) * sum(prev) + (sum(tn) / sum(n) * sum((1 - prev))) )
-        )
+    with(
+      micro,
+      (sum(tn) / sum(n) * sum((1 - prev))) /
+        ((1 - sum(tp) / sum(p)) * sum(prev) + (sum(tn) / sum(n) * sum((1 - prev))))
+    )
   )
   # Prevalence defined by the user. Defined once for all levels?
   expect_equal(
     npv(multi_ex, estimator = "micro", prevalence = .4)[[".estimate"]],
-    with(micro,
-         (sum(tn) / sum(n) * sum((1 - .4))) /
-           ( (1 - sum(tp) / sum(p)) * sum(.4) + (sum(tn) / sum(n) * sum((1 - .4))) )
+    with(
+      micro,
+      (sum(tn) / sum(n) * sum((1 - .4))) /
+        ((1 - sum(tp) / sum(p)) * sum(.4) + (sum(tn) / sum(n) * sum((1 - .4))))
     )
   )
 })
 
+test_that("work with class_pred input", {
+  skip_if_not_installed("probably")
+
+  cp_truth <- probably::as_class_pred(two_class_example$truth, which = 1)
+  cp_estimate <- probably::as_class_pred(two_class_example$predicted, which = 2)
+
+  fct_truth <- two_class_example$truth
+  fct_truth[1] <- NA
+
+  fct_estimate <- two_class_example$predicted
+  fct_estimate[2] <- NA
+
+  expect_identical(
+    npv_vec(fct_truth, cp_estimate),
+    npv_vec(fct_truth, fct_estimate)
+  )
+
+  expect_identical(
+    npv_vec(fct_truth, cp_estimate, na_rm = FALSE),
+    NA_real_
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    accuracy_vec(cp_truth, cp_estimate)
+  )
+})
+
 # ------------------------------------------------------------------------------
 
-test_that('Two class weighted - sklearn equivalent', {
+test_that("Two class weighted - sklearn equivalent", {
   py_res <- read_pydata("py-npv")
   r_metric <- npv
 
@@ -85,7 +115,7 @@ test_that('Two class weighted - sklearn equivalent', {
   )
 })
 
-test_that('Multi class weighted - sklearn equivalent', {
+test_that("Multi class weighted - sklearn equivalent", {
   py_res <- read_pydata("py-npv")
   r_metric <- npv
 
