@@ -1,23 +1,23 @@
-test_that('Two class', {
+test_that("Two class", {
   lst <- data_altman()
   pathology <- lst$pathology
   path_tbl <- lst$path_tbl
 
   expect_equal(
     spec(pathology, truth = "pathology", estimate = "scan")[[".estimate"]],
-    54/86
+    54 / 86
   )
   expect_equal(
     spec(path_tbl)[[".estimate"]],
-    54/86
+    54 / 86
   )
   expect_equal(
     spec(pathology, truth = pathology, estimate = "scan_na")[[".estimate"]],
-    53/85
+    53 / 85
   )
   expect_equal(
     spec(as.matrix(path_tbl))[[".estimate"]],
-    54/86
+    54 / 86
   )
 })
 
@@ -37,7 +37,7 @@ test_that("`event_level = 'second'` works", {
 
 # ------------------------------------------------------------------------------
 
-test_that('Three class', {
+test_that("Three class", {
   multi_ex <- data_three_by_three()
   micro <- data_three_by_three_micro()
 
@@ -59,7 +59,7 @@ test_that('Three class', {
 
 test_that("Binary `spec()` returns `NA` with a warning when undefined (tn + fp = 0) (#98)", {
   levels <- c("a", "b")
-  truth    <- factor(c("a", "a"), levels = levels)
+  truth <- factor(c("a", "a"), levels = levels)
   estimate <- factor(c("a", "b"), levels = levels)
 
   expect_snapshot(out <- spec_vec(truth, estimate))
@@ -73,16 +73,16 @@ test_that("Multiclass `spec()` returns averaged value with `NA`s removed + a war
   # When `a` is the event we get spec      = NA   = (tn = 0, fp = 0)
   # When `b` is the event we get a warning = 1/3  = (tn = 1, fp = 2)
   # When `c` is the event we get a warning = 3/3  = (tn = 3, fp = 0)
-  truth    <- factor(c("a", "a", "a"), levels = levels)
+  truth <- factor(c("a", "a", "a"), levels = levels)
   estimate <- factor(c("a", "b", "b"), levels = levels)
 
   expect_snapshot(out <- spec_vec(truth, estimate))
-  expect_equal(out, (1 + 1/3 + 1) / 3, tolerance = 0.000001)
+  expect_equal(out, (1 + 1 / 3 + 1) / 3, tolerance = 0.000001)
 })
 
 test_that("`NA` is still returned if there are some undefined spec values but `na.rm = FALSE`", {
   levels <- c("a", "b")
-  truth    <- factor(c("a", "a"), levels = levels)
+  truth <- factor(c("a", "a"), levels = levels)
   estimate <- factor(c("a", NA), levels = levels)
   expect_equal(spec_vec(truth, estimate, na_rm = FALSE), NA_real_)
   expect_warning(spec_vec(truth, estimate, na_rm = FALSE), NA)
@@ -99,12 +99,12 @@ test_that("two class with case weights is correct", {
 
   expect_identical(
     spec(df, truth, estimate, case_weights = case_weights)[[".estimate"]],
-    1/2
+    1 / 2
   )
 
   expect_identical(
     specificity(df, truth, estimate, case_weights = case_weights)[[".estimate"]],
-    1/2
+    1 / 2
   )
 })
 
@@ -133,3 +133,31 @@ test_that("`specificity()` has a metric name unique to it (#232)", {
     "specificity"
   )
 })
+
+test_that("work with class_pred input", {
+  skip_if_not_installed("probably")
+
+  cp_truth <- probably::as_class_pred(two_class_example$truth, which = 1)
+  cp_estimate <- probably::as_class_pred(two_class_example$predicted, which = 2)
+
+  fct_truth <- two_class_example$truth
+  fct_truth[1] <- NA
+
+  fct_estimate <- two_class_example$predicted
+  fct_estimate[2] <- NA
+
+  expect_identical(
+    specificity_vec(fct_truth, cp_estimate),
+    specificity_vec(fct_truth, fct_estimate)
+  )
+
+  expect_identical(
+    specificity_vec(fct_truth, cp_estimate, na_rm = FALSE),
+    NA_real_
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    specificity_vec(cp_truth, cp_estimate)
+  )
+})
