@@ -1,14 +1,14 @@
-test_that('Mean Absolute Percentage Error', {
+test_that("Mean Absolute Percentage Error", {
   ex_dat <- generate_numeric_test_data()
   not_na <- !is.na(ex_dat$pred_na)
 
   expect_equal(
     mape(ex_dat, truth = "obs", estimate = "pred")[[".estimate"]],
-    100 * mean(abs((ex_dat$obs - ex_dat$pred)/ex_dat$obs))
+    100 * mean(abs((ex_dat$obs - ex_dat$pred) / ex_dat$obs))
   )
   expect_equal(
     mape(ex_dat, obs, pred_na)[[".estimate"]],
-    100 * mean(abs((ex_dat$obs[not_na] - ex_dat$pred[not_na])/ex_dat$obs[not_na]))
+    100 * mean(abs((ex_dat$obs[not_na] - ex_dat$pred[not_na]) / ex_dat$obs[not_na]))
   )
 })
 
@@ -32,7 +32,7 @@ test_that("`mape()` computes expected values when singular `truth` is `0` (#271)
 test_that("Weighted results are the same as scikit-learn", {
   solubility_test$weights <- read_weights_solubility_test()
   zero_solubility <- solubility_test$solubility == 0
-  solubility_test_not_zero <- solubility_test[!zero_solubility,]
+  solubility_test_not_zero <- solubility_test[!zero_solubility, ]
 
   expect_equal(
     mape(solubility_test_not_zero, solubility, prediction, case_weights = weights)[[".estimate"]],
