@@ -1,4 +1,4 @@
-test_that('Traditional R^2', {
+test_that("Traditional R^2", {
   ex_dat <- generate_numeric_test_data()
   not_na <- !is.na(ex_dat$pred_na)
 
@@ -6,7 +6,7 @@ test_that('Traditional R^2', {
     rsq_trad(ex_dat, truth = "obs", estimate = "pred")[[".estimate"]],
     1 -
       (
-        sum((ex_dat$obs - ex_dat$pred)^2)/
+        sum((ex_dat$obs - ex_dat$pred)^2) /
           sum((ex_dat$obs - mean(ex_dat$obs))^2)
       )
   )
@@ -14,7 +14,7 @@ test_that('Traditional R^2', {
     rsq_trad(ex_dat, truth = "obs", estimate = "pred_na")[[".estimate"]],
     1 -
       (
-        sum((ex_dat$obs[not_na] - ex_dat$pred[not_na])^2)/
+        sum((ex_dat$obs[not_na] - ex_dat$pred[not_na])^2) /
           sum((ex_dat$obs[not_na] - mean(ex_dat$obs[not_na]))^2)
       )
   )
@@ -22,7 +22,7 @@ test_that('Traditional R^2', {
     rsq_trad(ex_dat, truth = "obs", estimate = rand)[[".estimate"]],
     1 -
       (
-        sum((ex_dat$obs - ex_dat$rand)^2)/
+        sum((ex_dat$obs - ex_dat$rand)^2) /
           sum((ex_dat$obs - mean(ex_dat$obs))^2)
       )
   )
@@ -30,7 +30,7 @@ test_that('Traditional R^2', {
     rsq_trad(ex_dat, obs, rand_na)[[".estimate"]],
     1 -
       (
-        sum((ex_dat$obs[not_na] - ex_dat$rand[not_na])^2)/
+        sum((ex_dat$obs[not_na] - ex_dat$rand[not_na])^2) /
           sum((ex_dat$obs[not_na] - mean(ex_dat$obs[not_na]))^2)
       )
   )
